@@ -7,7 +7,7 @@ __author__ = "P J Kershaw"
 __date__ = "15/02/10"
 __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: queryinterface.py 7694 2010-11-03 08:53:22Z pjkersha $"
+__revision__ = "$Id: queryinterface.py 7865 2011-02-02 14:40:21Z pjkersha $"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 import logging
 log = logging.getLogger(__name__)
@@ -188,7 +188,7 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
         if self.__issuerProxy is None:
             return None
         else:
-            return self.__issuerProxy.value
+            return self.__issuerProxy.format
 
     def _setIssuerFormat(self, value):
         if self.__issuerProxy is None:
@@ -359,8 +359,7 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
         """
     
         # Ignore non-matching path
-        if environ['PATH_INFO'] not in (self.mountPath, 
-                                        self.mountPath + '/'):
+        if environ['PATH_INFO'] not in (self.mountPath, self.mountPath + '/'):
             return self._app(environ, start_response)
           
         # Ignore non-POST requests
