@@ -8,7 +8,7 @@ __date__ = "21/08/09"
 __copyright__ = "(C) 2009 Science and Technology Facilities Council"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = '$Id: test_attributeservice.py 7694 2010-11-03 08:53:22Z pjkersha $'
+__revision__ = '$Id: test_attributeservice.py 7865 2011-02-02 14:40:21Z pjkersha $'
 import unittest
 from uuid import uuid4
 from datetime import datetime, timedelta
@@ -65,14 +65,7 @@ class TestAttributeServiceMiddleware(object):
             (ndg.saml.saml2.binding.soap.server.wsgi.queryinterface.SOAPQueryInterfaceMiddleware)
             """
             response.issueInstant = datetime.utcnow()
-            response.id = str(uuid4())
-            response.issuer = Issuer()
-            
-            # SAML 2.0 spec says format must be omitted
-            #response.issuer.format = Issuer.X509_SUBJECT
-            response.issuer.value = \
-                            "/O=NDG/OU=BADC/CN=attributeauthority.badc.rl.ac.uk"
-            
+            response.id = str(uuid4())            
             response.inResponseTo = query.id
 
             if query.issuer.value not in self.__class__.VALID_QUERY_ISSUERS:
